@@ -77,7 +77,7 @@ def plot_mwu(
                 if kind == 'box':
                     sns.boxplot(y = density[ct], x = adata.obs[cond], hue = adata.obs[cond], ax = ax, fliersize = 0, palette = palette, dodge = False)
                     sns.swarmplot(y = density[ct], x = adata.obs[cond], color = 'black', ax = ax, s = 3)
-                if kind == 'box-line':
+                elif kind == 'box-line':
                     sns.boxplot(y = density[ct], x = adata.obs[cond], hue = adata.obs[cond], ax = ax, fliersize = 0, palette = palette, dodge = False, boxprops=dict(alpha=.65,), whiskerprops=dict(alpha=0.5,), capprops = dict(alpha = 0.7), medianprops = dict(alpha=0.7,), meanprops = dict(alpha=0.7,), width = 0.7)
                     sns.swarmplot(y = density[ct], x = adata.obs[cond], color = 'black', ax = ax, s = 2, alpha=0.5)
                     sns.lineplot(y = density[ct], x = adata.obs[cond], ax = ax, color = 'black', estimator='median', markers=True, dashes=False, linewidth = 2, marker='o', markeredgecolor='black')
@@ -91,10 +91,11 @@ def plot_mwu(
                 ax.set_title(ct)
                 ax.set_ylabel('')
                 ax.set_xlabel('')
-                if y_max:
-                    ax.set_ylim(0, y_max)
 
                 y1 = density[ct].max() * 1.05
+                if y_max:
+                    ax.set_ylim(0, y_max)
+                    y1 = y_max * 0.85
                 r = y1 * 0.03
                 l = adata.obs[cond].cat.categories.tolist()
 
@@ -115,7 +116,6 @@ def plot_mwu(
                         ax.text(s = pval, x = 0.5, y = y1, fontsize = 8, va = 'bottom', ha = 'center')
 
                     else:
-                        p = sig_mwu_.iloc[i]['adj. p-val']
                         
                         ax.plot([pair[0], pair[1]], [y1 + r*sig_n, y1 + r*sig_n], lw=line_width, c='black')
                         ax.text(s = pval, x = pair[1], y = y1 + r*sig_n, fontsize = 8, va = 'top', ha = 'left')
@@ -202,7 +202,58 @@ def celltype_heatmap(
         plt.savefig(f'{out_dir}/celltype_proportion.pdf', bbox_inches = 'tight')
         plt.close()
 
+def spatial(
+    adata: anndata.AnnData,
+    color: tp.Union[str, list],
+    spot_size: int = 10,
+    edges: tp.Any = None,
+    edges_knn: int = 15,
+    edges_radius: float = 40,
+    *args,
+    **kwargs,
+):
+    ''' Function to plot spatial plots from AnnData. Spatial coordinates must be stored in adata.uns['spatial'] for this function to work.
 
+    Args:
+        adata (anndata.AnnData): AnnData object to spatial plot
+        color (tp.Union[str, list]): color of points in spatial plot. Variable must be stored in 'obs' layer
+        spot_size (int): default size of each cells
+        edges (tp.Any): Whether to connect cells with edges. Default is to not plot edges. Two options are 'KNN' and 'radius'. If 'KNN', numbers of neighbors are defined by 'edges_knn'. If 'radius', number of neighbors are defined by 'edges_radius'.
+        edges_knn (int): number of nearest neighbors in KNN edges
+        edges_radius (float): threshold distance for neighborhood definition    '''
+    import squidpy as sq
+    
+    a = adata.copy()
+
+    if edges == 'KNN':
+        sq.gr.spatial_neighbors(a, coord_type = 'generic', n_neighs = edges_knn)
+    elif edges == 'radius':
+        sq.gr.spatial_neighbors(a, coord_type = 'generic', radius = edges_radius)
+    else:
+        logger.info("'edges' is neither 'KNN', nor 'radius'. Plotting figure without edges")
+        sc.pl.spatial(
+            a,
+            color = [color],
+            spot_size = spot_size,
+            frameon = False,
+            show = False,
+            *args,
+            **kwargs,
+        )
+
+        return
+
+    sc.pl.spatial(
+        a,
+        color = [color],
+        spot_size = spot_size,
+        edges = True,
+        neighbors_key = 'spatial_neighbors',
+        frameon = False,
+        show = False,
+        *args,
+        **kwargs
+    )
 
 def add_scale_box_to_fig(
     img,
