@@ -165,7 +165,7 @@ def celltype_density(
     density.X = density.X / np.array(density.obs['ROI_area'])[:, None]
     
     for cond in condition_keys:
-        if data.uns[f'{cond}_colors']:
+        if f'{cond}_colors' in data.uns:
             density.uns[f'{cond}_colors'] = data.uns[f'{cond}_colors']
     
     return density
