@@ -1,4 +1,5 @@
 from imc_analysis.types import Path
+from imc_analysis.logging import *
 import typing as tp
 
 def parse_yaml(yaml_file: Path) -> tp.Union[dict, None]:
@@ -6,14 +7,34 @@ def parse_yaml(yaml_file: Path) -> tp.Union[dict, None]:
     Parse project config yaml file
     """
     import yaml
-
+    logger.info(f'Opening project config file: {yaml_file}...')
     with open(yaml_file, "r") as stream:
         try:
             metadata = yaml.safe_load(stream)
+            logger.info(f'Successfully opened project config file: {yaml_file}...')
             return metadata
         except yaml.YAMLError as exc:
+            logger.error(f'Error opening config file: {yaml_file}')
             print(exc)
 
+def download(url: str, save: Path) -> tp.Union[dict, None]:
+    """
+    Download file from url
+    """
+    # if metadata not found, download
+    import os
+    if not os.path.exists(save):
+        from tqdm import tqdm
+        import requests
+
+        os.makedirs(save, exist_ok = True)
+        response = requests.get(url, stream=True)
+        
+        with open(save, "wb") as handle:
+            for data in tqdm(response.iter_content()):
+                handle.write(data)
+            handle.close()
+
 
 def init(project, yaml, panel):
     """
